# PyUDP

## Overview
PyUDP is a simple wrapper for UDP communication in Python.  
Multicast is also supported.

## Installation
You can install PyUDP using the following command:  

```bash
pip install pyudp
or  
pip install git+https://github.com/takumi-nishimura/PyUDP@v0.1.0
```

## Usage
Please refer to the sample code in /tests.
